#include "qtnut3dialogimpl.h"

#include <qlistbox.h>
#include <qpushbutton.h>
#include <qfiledialog.h>
#include <qstring.h>
#include <qstringlist.h>
#include <qspinbox.h>
#include <qcheckbox.h>
#include <qmessagebox.h>
#include "nuticon.xpm"


#include "SNut.h"


qtnut3DialogImpl::qtnut3DialogImpl( QWidget* parent, const char* name, bool modal, WFlags f )
	: qtnut3Dialog( parent, name, modal, f )
{

	// Add your code
	setButtonEnable();
	spinBoxStep->setMinValue(1);
	spinBoxInit->setMinValue(1);
	spinBoxStep->setMaxValue(PARTNUM_STEP_MAX);
	spinBoxInit->setMaxValue(PARTNUM_INIT_MAX);
	spinBoxStep->setValue(1);
	spinBoxInit->setValue(1);

}

void qtnut3DialogImpl::setButtonEnable()
{
	int nCount = listFile->count();
	int nSelect = listFile->currentItem();
    buttonDel->setEnabled(nCount>0);
    buttonExecute->setEnabled(nCount>0);
	buttonUp->setEnabled(nCount>0 && nSelect>=1); 
    buttonDown->setEnabled(nCount>0 && nSelect>=0 && nSelect<nCount-1);
}

void qtnut3DialogImpl::OnButtonUp()
{
	int nCount = listFile->count();
	if(nCount < 2) return;
	int nSelect = listFile->currentItem();
	if(nSelect>0){
		QString string =listFile->currentText(); 
		listFile->removeItem(nSelect);
		nCount--;
		nSelect--;
		listFile->insertItem(string,nSelect);
		listFile->setSelected (nSelect,true);
	}
	setButtonEnable();
}

void qtnut3DialogImpl::OnButtonDown()
{
	int nCount = listFile->count();
	if(nCount < 2) return;
	int nSelect = listFile->currentItem();
	if(nSelect<nCount-1){
		QString string =listFile->currentText(); 
		listFile->removeItem(nSelect);
		nCount--;
		nSelect++;
		listFile->insertItem(string,nSelect);
		listFile->setSelected (nSelect,true);
	}
	setButtonEnable();
}

void qtnut3DialogImpl::OnButtonRef()
{
	QStringList sl=QFileDialog::getOpenFileNames("*.ce3");
	if(!sl.isEmpty()){
		for ( QStringList::Iterator it = sl.begin(); it != sl.end(); ++it ){
			listFile->insertItem(*it);
		}
	}
	if(listFile->count() > 0){
		listFile->setSelected (0,true);
	}
	setButtonEnable();

}

void qtnut3DialogImpl::OnButtonDel()
{
	int nCount = listFile->count();
	if(nCount == 0) return;
	int nSelect = listFile->currentItem();
	if(nSelect<0)nSelect = 0;
	listFile->removeItem(nSelect);
	nCount--;
	if(nCount>0){
		if(nSelect>=nCount)nSelect= nCount-1;
		if(nSelect>=0)listFile->setSelected (nSelect,true);
	}
	setButtonEnable();
}

void qtnut3DialogImpl::OnButtonExec()
{
	SNut snut;

	int nCount = listFile->count();
	if(nCount==0){
		return;
	}
	QString str;
	int readCount=0;
	for(int n=0;n<nCount;n++){
		str = listFile->text(n);
		snut.readFile(str.local8Bit());
	}
	if(snut.fileCount()==0)return;

	int nInit=spinBoxInit->value();
	if(nInit<1 || nInit>PARTNUM_INIT_MAX){							//ϰϳʤ
		spinBoxInit->setValue(1);
		QMessageBox::information(this,QString::fromLocal8Bit("Qt-NUT"),QString::fromLocal8Bit("Out of range : INIT VALUE"));
		return;
	}
	int nStep=spinBoxStep->value();
	if(nStep<1 || nStep>PARTNUM_STEP_MAX){							//ϰϳʤ
		spinBoxStep->setValue(1);
		QMessageBox::information(this,QString::fromLocal8Bit("Qt-NUT"),QString::fromLocal8Bit("Out of range : STEP VALUE"));
		return;
	}

	bool anumMode = checkBoxAutoNum->isChecked();

	if(anumMode){
		snut.anum(nInit,nStep);
	}else{
		snut.renum(nInit,nStep);
	}
	snut.saveFiles();
	QMessageBox::information(this,QString::fromLocal8Bit("Qt-NUT"),QString::fromLocal8Bit("Finished all process."));

}

void qtnut3DialogImpl::OnListSelChange()
{
	setButtonEnable();
}

void qtnut3DialogImpl::OnButtonAbout()
{
	QPixmap icon( (const char**)nuticon );

	QMessageBox mb(this);

	mb.setMinimumWidth(400);
	mb.setCaption("About  Qt-NUT");
	mb.setTextFormat(RichText);
	mb.setText(	
			"<center><b>Qt-NUT  Version 0.2</b><br><br>"
			"Copyright(C) 2004 H.Okada(Suigyodo)<br>"
			"Qt-NUT comes with absolutely no warranty.<br>"
			"URL  http://www.suigyodo.com/online<br>"
			"E-Mail  hitoshi@suigyodo.com</center>"
		);
	mb.setIconPixmap(icon);
	//mb.adjustSize();
	mb.exec();
}
